==> jc-1.4.0.tar.gz: java/lang/ExceptionInInitializerError.h <==
// public class java.lang.ExceptionInInitializerError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3d51913bd8835df6 java_lang_ExceptionInInitializerError
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_ExceptionInInitializerError_H_
#define _JC_java_lang_ExceptionInInitializerError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_ExceptionInInitializerError$sub_refs	_jc_java_lang_ExceptionInInitializerError$sub_refs;
typedef struct _jc_java_lang_ExceptionInInitializerError$sub_nonrefs	_jc_java_lang_ExceptionInInitializerError$sub_nonrefs;
typedef struct _jc_java_lang_ExceptionInInitializerError$refs	_jc_java_lang_ExceptionInInitializerError$refs;
typedef struct _jc_java_lang_ExceptionInInitializerError$nonrefs	_jc_java_lang_ExceptionInInitializerError$nonrefs;
typedef struct _jc_java_lang_ExceptionInInitializerError$object	_jc_java_lang_ExceptionInInitializerError$object;

typedef struct _jc_java_lang_ExceptionInInitializerError$fields_struct	_jc_java_lang_ExceptionInInitializerError$fields_struct;
typedef const struct _jc_java_lang_ExceptionInInitializerError$vmethods	_jc_java_lang_ExceptionInInitializerError$vmethods;
typedef const struct _jc_java_lang_ExceptionInInitializerError$vtable	_jc_java_lang_ExceptionInInitializerError$vtable;
typedef const struct _jc_java_lang_ExceptionInInitializerError$vtype	_jc_java_lang_ExceptionInInitializerError$vtype;

// Class fields structure
struct _jc_java_lang_ExceptionInInitializerError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ExceptionInInitializerError$fields_struct _jc_java_lang_ExceptionInInitializerError$class_fields;

// Constructors
extern void _jc_java_lang_ExceptionInInitializerError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *);
extern void _jc_java_lang_ExceptionInInitializerError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_ExceptionInInitializerError$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ExceptionInInitializerError$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *);
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ExceptionInInitializerError$method$getException$74d033e489a87383(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ExceptionInInitializerError$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_ExceptionInInitializerError$method_info$getException$74d033e489a87383;

// Virtual methods structure
struct _jc_java_lang_ExceptionInInitializerError$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *);
	struct _jc_java_lang_Throwable$object	*(*getException$74d033e489a87383)(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *);
};

// Vtable
struct _jc_java_lang_ExceptionInInitializerError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_ExceptionInInitializerError$vmethods	java_lang_ExceptionInInitializerError;
};

// Vtype
struct _jc_java_lang_ExceptionInInitializerError$vtype {
	_jc_type			type;
	_jc_java_lang_ExceptionInInitializerError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ExceptionInInitializerError$sub_refs {
	struct _jc_java_lang_Throwable$object	*exception;
};

// Reference instance fields (object)
struct _jc_java_lang_ExceptionInInitializerError$refs {
    _jc_java_lang_ExceptionInInitializerError$sub_refs	java_lang_ExceptionInInitializerError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ExceptionInInitializerError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ExceptionInInitializerError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_ExceptionInInitializerError$sub_nonrefs	java_lang_ExceptionInInitializerError;
};

// Object instance structure
struct _jc_java_lang_ExceptionInInitializerError$object {
	_jc_java_lang_ExceptionInInitializerError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ExceptionInInitializerError$vtype	*vtype;
	_jc_java_lang_ExceptionInInitializerError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ExceptionInInitializerError$vtype _jc_java_lang_ExceptionInInitializerError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ExceptionInInitializerError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ExceptionInInitializerError$class_object;

#endif	/* _JC_java_lang_ExceptionInInitializerError_H_ */

==> jc-1.4.6.tar.gz: java/lang/ExceptionInInitializerError.h <==
// public class java.lang.ExceptionInInitializerError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3d51913bd8835df6 java_lang_ExceptionInInitializerError
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_ExceptionInInitializerError_H_
#define _JC_java_lang_ExceptionInInitializerError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_ExceptionInInitializerError$sub_refs	_jc_java_lang_ExceptionInInitializerError$sub_refs;
typedef struct _jc_java_lang_ExceptionInInitializerError$sub_nonrefs	_jc_java_lang_ExceptionInInitializerError$sub_nonrefs;
typedef struct _jc_java_lang_ExceptionInInitializerError$refs	_jc_java_lang_ExceptionInInitializerError$refs;
typedef struct _jc_java_lang_ExceptionInInitializerError$nonrefs	_jc_java_lang_ExceptionInInitializerError$nonrefs;
typedef struct _jc_java_lang_ExceptionInInitializerError$object	_jc_java_lang_ExceptionInInitializerError$object;

typedef struct _jc_java_lang_ExceptionInInitializerError$fields_struct	_jc_java_lang_ExceptionInInitializerError$fields_struct;
typedef const struct _jc_java_lang_ExceptionInInitializerError$vmethods	_jc_java_lang_ExceptionInInitializerError$vmethods;
typedef const struct _jc_java_lang_ExceptionInInitializerError$vtable	_jc_java_lang_ExceptionInInitializerError$vtable;
typedef const struct _jc_java_lang_ExceptionInInitializerError$vtype	_jc_java_lang_ExceptionInInitializerError$vtype;

// Class fields structure
struct _jc_java_lang_ExceptionInInitializerError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ExceptionInInitializerError$fields_struct _jc_java_lang_ExceptionInInitializerError$class_fields;

// Constructors
extern void _jc_java_lang_ExceptionInInitializerError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ExceptionInInitializerError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ExceptionInInitializerError$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ExceptionInInitializerError$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ExceptionInInitializerError$method$getException$74d033e489a87383(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ExceptionInInitializerError$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_ExceptionInInitializerError$method_info$getException$74d033e489a87383;

// Virtual methods structure
struct _jc_java_lang_ExceptionInInitializerError$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Throwable$object	*(*getException$74d033e489a87383)(_jc_env *, struct _jc_java_lang_ExceptionInInitializerError$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ExceptionInInitializerError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_ExceptionInInitializerError$vmethods	java_lang_ExceptionInInitializerError;
};

// Vtype
struct _jc_java_lang_ExceptionInInitializerError$vtype {
	_jc_type			type;
	_jc_java_lang_ExceptionInInitializerError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ExceptionInInitializerError$sub_refs {
	struct _jc_java_lang_Throwable$object	*exception;
};

// Reference instance fields (object)
struct _jc_java_lang_ExceptionInInitializerError$refs {
    _jc_java_lang_ExceptionInInitializerError$sub_refs	java_lang_ExceptionInInitializerError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ExceptionInInitializerError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ExceptionInInitializerError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_ExceptionInInitializerError$sub_nonrefs	java_lang_ExceptionInInitializerError;
};

// Object instance structure
struct _jc_java_lang_ExceptionInInitializerError$object {
	_jc_java_lang_ExceptionInInitializerError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ExceptionInInitializerError$vtype	*vtype;
	_jc_java_lang_ExceptionInInitializerError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ExceptionInInitializerError$vtype _jc_java_lang_ExceptionInInitializerError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ExceptionInInitializerError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ExceptionInInitializerError$class_object;

#endif	/* _JC_java_lang_ExceptionInInitializerError_H_ */
